"""Imports for Python API.

This file is MACHINE GENERATED! Do not edit.
Generated by: tensorflow/tools/api/generator/create_python_api.py script.
"""
from tensorflow.python.lib.io.python_io import TFRecordCompressionType
from tensorflow.python.lib.io.python_io import TFRecordOptions
from tensorflow.python.lib.io.python_io import TFRecordWriter
from tensorflow.python.lib.io.python_io import tf_record_iterator